@@ -68,14 +68,9 @@ class User(db.Model):
     __tablename__ = 't_roles'
     __table_args__ = {'schema': 'utilisateurs'}
 
-    TABLE_ID = Sequence(
-        't_roles_id_role_seq',
-        schema="utilisateurs",
-    )
     groupe = db.Column(db.Boolean, default=False)
     id_role = db.Column(
         db.Integer,
-        TABLE_ID,
         primary_key=True,
     )
 
@@ -217,7 +212,7 @@ class Profils(db.Model):
     nom_profil = db.Column(db.Unicode)
     desc_profil = db.Column(db.Unicode)
 
-    applications = relationship("Application", secondary=profils_for_app)
+    applications = relationship("Application", secondary=profils_for_app, back_populates="profils")
 
 
 @serializable
@@ -233,7 +228,7 @@ class Application(db.Model):
     desc_application = db.Column(db.Unicode)
     id_parent = db.Column(db.Integer)
 
-    profils = relationship(Profils, secondary=profils_for_app)
+    profils = relationship(Profils, secondary=profils_for_app, back_populates="applications")
 
     def __repr__(self):
         return "<Application {!r}>".format(self.nom_application)
@@ -350,6 +345,38 @@ class AppRole(db.Model):
     id_organisme = db.Column(db.Integer)
     identifiant = db.Column(db.Unicode)
 
+    application = db.relationship(Application)
+
     def as_dict(self):
         cols = (c for c in self.__table__.columns)
         return {c.name: getattr(self, c.name) for c in cols}
+
+
+cor_role_liste = db.Table("cor_role_liste",
+    db.Column(
+        "id_role",
+        db.Integer,
+        ForeignKey("utilisateurs.t_roles.id_role"),
+        primary_key=True,
+    ),
+    db.Column(
+        "id_liste",
+        db.Integer,
+        ForeignKey("utilisateurs.t_listes.id_liste"),
+        primary_key=True,
+    ),
+    schema="utilisateurs",
+)
+
+
+@serializable
+class UserList(db.Model):
+    __tablename__ = "t_listes"
+    __table_args__ = {"schema": "utilisateurs"}
+
+    id_liste = db.Column(db.Integer, primary_key=True)
+    code_liste = db.Column(db.Unicode(length=20))
+    nom_liste = db.Column(db.Unicode(length=50))
+    desc_liste = db.Column(db.Unicode)
+
+    users = db.relationship(User, secondary=cor_role_liste)
